﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2015 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System.Drawing;
using System.Windows.Forms;
using HeuristicLab.Common.Resources;

namespace HeuristicLab.Visualization {
  public class MoveChartMode : ChartMode {
    public override Image Image { get { return VSImageLibrary.Breakpoint; } }
    public override string ToolTip { get { return "Move"; } }

    public override Cursor Cursor {
      get { return cursor ?? (cursor = new Cursor(typeof(ChartControl), "Resources.Hand.cur")); }
    }

    public MoveChartMode(ChartControl control) : base(control) { }

    public override void HandleOnMouseUp(object sender, MouseEventArgs e) {
      base.HandleOnMouseUp(sender, e);

      switch (e.Button) {
        case MouseButtons.Middle:
          chartControl.Chart.Unzoom();
          break;
      }
    }

    public override void HandleOnMouseMove(object sender, MouseEventArgs e) {
      base.HandleOnMouseMove(sender, e);

      try {
        switch (e.Button) {
          case MouseButtons.Left:
            var previousWorldLocation = chartControl.Chart.TransformPixelToWorld(previousLocation);
            var worldLocation = chartControl.Chart.TransformPixelToWorld(e.Location);
            var offset = worldLocation - previousWorldLocation;
            chartControl.Chart.Move(new Offset(-1 * offset.DX, -1 * offset.DY));
            break;
        }
      } finally {
        previousLocation = e.Location;
        chartControl.PictureBox.Update();
      }
    }
  }
}
